@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: battstat.h 9983 2006-09-22 00:20:32Z ryanl $
+ $Id: battstat.h 10289 2007-07-17 06:20:57Z jhaitsma $
  */
 
 #ifndef _battstat_h_
@@ -111,9 +111,6 @@ typedef struct _ProgressData {
   /* label changed type (% <-> h:mm) and must be refreshed */
   gboolean refresh_label;
 
-  /* tooltip attached to 'applet' */
-  GtkTooltips *tip;
-
   /* so we don't have to alloc/dealloc this every refresh */
   GdkGC *pixgc;
 
@@ -126,7 +123,6 @@ typedef struct _ProgressData {
   GtkWidget *percent;
 
   /* dialog boxes that might be displayed */
-  GtkWidget *about_dialog;
   GtkDialog *prop_win;
   GtkWidget *battery_low_dialog;
 
