@@ -21,7 +21,11 @@
 #define __UTIL_H__
 
 #include <glib.h>
+#include <gtk/gtkwindow.h>
 
 gchar * get_current_date(const gchar *format);
+void	xstuff_change_workspace (GtkWindow *window,
+			         int        new_space);
+int	xstuff_get_current_workspace (GtkWindow *window);
 
 #endif /* #ifndef __UTIL_H__ */
